# command line option --define "__with_erase=--with-erase"
%define erase     %{?_with_erase:-erase}

# command line option --define "_with_echo=--with-echo"
# adds verbose output during install

# various defines

# be very careful about redefining these..
%define mysqldir     /var/lib/mysql
%define mysqldpid    /var/run/mysqld/mysqld.pid
%define mysqldctrl   /etc/rc.d/init.d/mysqld
%define htmldir      /var/www/html

# altering these requires altering them in the install.php file also
%define database        poplar_genealogy_db
%define admin_user      poplar
%define admin_password  poplar

# more config stuff
%define root_password root
%define netname `uname -n`

%define topdir poplar
%define alt_version 2-0

# workaround for BUGZILLA #
%define stop_timeout 20
%define mysql_ping /usr/bin/mysqladmin -uUNKNOWN_MYSQL_USER ping

Summary:	GEDCON 5.5 php server
Name:		poplargedcomviewer
Version:	2.0
Release:	3_rh9
Requires:	httpd >= 2.0.40
Requires:	php >= 4.2.2
Requires:	mysql = 3.23.54a
Requires:	coreutils >= 4.5.3
Requires:	bash >= 2.05b
Requires:	chkconfig >= 1.3.8
Requires:	rpm-build >= 4.2
BuildArchitectures: noarch
BuildRequires:  bash >= 2.05b
BuildRequires:  coreutils >= 4.5.3
BuildRequires:  findutils >= 4.1.7-9
BuildRequires:  sed >= 4.0.5-1
Group:		Applications/Genealogy
License:	GPL
Source0:	%{topdir}-%{alt_version}.tgz
URL:		http://download.sourceforge.net/pub/sourceforge/poplar
Packager:	Byron Young
BuildRoot:	%{_tmppath}/%{name}-%{version}-root
Vendor:		Byron_Young
Conflicts:	%{name} < %{version}
%{?_with_erase:Patch0:	%{name}-%{version}-install.php.patch}

%description
The %{name} project parses GEDCOM 5.5 genealogy files and displays them
on the internet in a format similar to PAF. All it requires to run is a php
enabled web server, a mySQL server,  and a gedcom file. It is easily
customizable for use on many different web sites.

%{?_with_erase:WARNING %{name} built with erase option.}
%{?_with_echo:%{name} built with echo option.}
The %{name} distributed package has been built without the erase option.
Please! Do not distribute %{name} in a package that has been built with the
erase option. As distributed, the %{name} package is installed, and the
mySQL database must be set up manually. The removal script leaves the mySQL
database untouched, and follows normal rpm removal rules.

This package, when built with the erase option is intended specifically for
NEW installations of RedHat 9.0 only, in a small office/ home office
environment. If
--define "_with_erase=--with-erase"
is defined during rebuild, the resulting RPMS will erase any existing mySQL
databases, erase any existing %{name} installation, and return the mySQL
server database to an initialized state. The install script will then add
mysql user %{admin_user} (password %{admin_password}), create a mysql
database %{database}, set the mysql root user password to %{root_password},
add mysqld to the autostart sequence, and start the mysqld server.
Once installed, just start the webserver, access
http://localhost/%{name}/install.php
and follow instructions.

To rebuild the package with erase option:
rpm -i %{name}-%{version}-%{release}.src.rpm
cd /usr/src/redhat/SPECS
rpmbuild -ba --define "_with_erase=--with-erase" --define "_with_echo=--with-echo" %{name}.spec
cd /usr/src/redhat/RPMS/noarch
rpm -i %{name}-%{version}-%{release}.noarch.rpm

WARNING: The install AND!! removal script BOTH erase all existing mySQL
databases AND reinitialize the mySQL database, plus erases
all traces of the %{name} installation, including any uploaded
ged files and any added information.

The _with_echo option prints additional install information to standard output,
and is intended for manual installation. For quiet installation, (good for use
with automated install), rebuild without the _with_echo option.

As a rule of thumb, automated installations should never use _with_erase or
_with_echo.

%prep
%setup -n %{topdir}
%{?_with_erase:%patch0 -p0 -b .orig}
for i in `find . -name CVS -print`; do rm -rf $i; done

%build
find ./ -type d -print | sed 's/^.\///'\
  | sed '/^$/d' | \
  sed 's/^/%%dir %%attr(550,apache,apache) %%{htmldir}\/%%{name}\//' \
  > dirslist.txt
echo "%%dir %%attr(750,apache,apache) \
	%%{htmldir}/%%{name}/gedcom" >> dirslist.txt
echo "%%dir %%attr(750,apache,apache) \
	%%{htmldir}/%%{name}/include/smarty/templates_c" >> dirslist.txt
cd ..

%install
test "$RPM_BUILD_ROOT" != "/" && rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{htmldir}/%{name}
cp -dpR * $RPM_BUILD_ROOT%{htmldir}/%{name}
rm -f $RPM_BUILD_ROOT%{htmldir}/%{name}/dirslist.txt
#rm -rf $RPM_BUILD_ROOT%{htmldir}/%{name}/docs

%clean
test "$RPM_BUILD_ROOT" != "/" && rm -rf $RPM_BUILD_ROOT
exit 0

%pre
if [ "%{erase}" = "-erase" ]; then
	if [ -z %{mysqldir} ]; then
		echo mysqldir not defined properly.
		exit 1
		fi
	if [ %{mysqldir} = "/" ]; then
		echo mysqldir not defined properly.
		exit 1
		fi
	%{?_with_echo:echo "%{name} built with erase option."}
	%{?_with_echo:echo "Hit ctrl-c to stop within %{stop_timeout} seconds."}
	%{?_with_echo:sleep %{stop_timeout}}
 	test -d %{_tmppath} -a -w %{_tmppath} || (\
	    %{?_with_echo:echo "%{_tmppath} must exist and be writeable";}\
	    exit 1;)
	test -d %{htmldir}/%{name} && (\
	    %{?_with_echo:echo "Erasing existing %{name}";}\
            rm -rf %{htmldir}/%{name};)
     fi
exit 0

%post
# mysqld_down
# returns
# 0 success, mysqld down
# 1 failed, stop failed for some reason
mysqld_down(){
local loop
%{mysql_ping} > /dev/null 2>&1
test $? -ne 0 && return 0
%{mysqldctrl} stop > /dev/null 2>&1&
loop=%{stop_timeout}
while test $loop -ne 0; do
    %{mysql_ping} > /dev/null 2>&1
    test $? -ne 0 && return 0
    loop=`expr $loop - 1`
    sleep 1
    done
return 1
}

# mysqld_up
# returns
# 0 success, mysqld running
# 1 failed, start failed for some reason
mysqld_up(){
local loop
%{mysql_ping} > /dev/null 2>&1
test $? -eq 0 && return 0
%{mysqldctrl} start > /dev/null 2>&1&
loop=%{stop_timeout}
while test $loop -ne 0; do
    %{mysql_ping} > /dev/null 2>&1
    test $? -eq 0 && return 0
    loop=`expr $loop - 1`
    sleep 1
    done
return 1
}

if [ "%{erase}" = "-erase" ]; then
    %{?_with_echo:echo "Stopping mysqld"}
    mysqld_down
    test $? -ne 0 && { %{?_with_echo:echo "mysqld stop failed";} exit 1; }
    %{?_with_echo:echo "Deleting existing mysql database. Creating new."}
    (cd %{mysqldir};\
        test "`/bin/pwd`" = "%{mysqldir}" && (\
		rm  -rf *;\
		);\
        /usr/bin/mysql_install_db > /dev/null 2>&1;\
	)
    %{?_with_echo:echo "Starting mysqld"}
    mysqld_up
    test $? -ne 0 && { %{?_with_echo:echo "Start failed. Exiting.";} exit 1; }

%{__cat} > %{_tmppath}/install_mysql.txt <<EOF

insert into
host(host,db,Select_priv,Insert_priv,Update_priv,Delete_priv,Create_priv,Drop_priv)
values('localhost','%%','Y', 'Y', 'Y', 'Y', 'Y', 'Y');

insert into
host(host,db,Select_priv,Insert_priv,Update_priv,Delete_priv,Create_priv,Drop_priv)
values('%{netname}','%%','Y', 'Y', 'Y', 'Y', 'Y', 'Y');

insert into
user (host,user,password)
values('localhost','%{admin_user}',password('%{admin_password}'));

insert into
user (host,user,password)
values('%{netname}','%{admin_user}',password('%{admin_password}'));

insert into
db (host,db,user,Select_priv,Insert_priv,Update_priv,Delete_priv,Create_priv,Drop_priv)
values ('localhost','%{database}','%{admin_user}','Y','Y','Y','Y','Y','Y');

insert into
db (host,db,user,Select_priv,Insert_priv,Update_priv,Delete_priv,Create_priv,Drop_priv)
values ('%{netname}','%{database}','%{admin_user}','Y','Y','Y','Y','Y','Y');
EOF

	# create the database
	%{?_with_echo:echo "Creating %{database}"}
	/usr/bin/mysqladmin -u root create %{database}
	test $? -ne 0 && exit 1
	sleep 5
	%{?_with_echo:echo "Reloading."}
	/usr/bin/mysqladmin -u root reload
	sleep 5
	%{?_with_echo:echo "Initializing database %{database}"}
	/usr/bin/mysql -u root mysql < %{_tmppath}/install_mysql.txt
	rm -f %{_tmppath}/install_mysql.txt
	/usr/bin/mysqladmin -u root password %{root_password}
	/usr/bin/mysqladmin -u root -h %{netname} password %{root_password}
	%{?_with_echo:echo "Restarting mysqld"}
	mysqld_down
	mysqld_up
	%{?_with_echo:echo "Adding mysqld to startup"}
	/sbin/chkconfig mysqld on
	fi
exit 0

%postun
# mysqld_down
# returns
# 0 success, mysqld down
# 1 failed, stop failed for some reason
mysqld_down(){
local loop
%{mysql_ping} > /dev/null 2>&1
test $? -ne 0 && return 0
%{mysqldctrl} stop > /dev/null 2>&1&
loop=%{stop_timeout}
while test $loop -ne 0; do
    %{mysql_ping} > /dev/null 2>&1
    test $? -ne 0 && return 0
    loop=`expr $loop - 1`
    sleep 1
    done
return 1
}

# mysqld_up
# returns
# 0 success, mysqld running
# 1 failed, start failed for some reason
mysqld_up(){
local loop
%{mysql_ping} > /dev/null 2>&1
test $? -eq 0 && return 0
%{mysqldctrl} start > /dev/null 2>&1&
loop=%{stop_timeout}
while test $loop -ne 0; do
    %{mysql_ping} > /dev/null 2>&1
    test $? -eq 0 && return 0
    loop=`expr $loop - 1`
    sleep 1
    done
return 1
}

if [ "%{erase}" = "-erase" ]; then
    %{?_with_echo:echo "Built with erase option."}
    %{?_with_echo:echo "Hit ctrl-c to stop within %{stop_timeout} seconds."}
    %{?_with_echo:sleep %{stop_timeout}}
    mysqld_down
    test $? -ne 0 && { %{?_with_echo:echo "Start failed. Exiting.";} exit 1; }
    %{?_with_echo:echo "Deleting, reinitializing mysql database"}
    (cd %{mysqldir};\
        test "`/bin/pwd`" = "%{mysqldir}" && rm -rf *;\
	/usr/bin/mysql_install_db > /dev/null 2>&1;\
	)
    test -d %{htmldir}/%{name} && {\
	%{?_with_echo:echo "Deleting remaining %{name} installation";}\
	rm -rf %{htmldir}/%{name}; }
    fi
exit 0

%files -f dirslist.txt
%defattr(440, apache, apache, -)
%dir %attr(750,apache,apache) %{htmldir}/%{name}
%{htmldir}/%{name}/*
%doc docs/*


%changelog
* Tue Feb 24 2004 Byron Young <spamiccling@yahoo.com>
- packaged 2.0 version.
- adjusted automatic installation scripts.

* Tue Nov 4 2003 Byron Young <spamiccling@yahoo.com>
- Added _with_echo option.
- Added additional erase option install checks.
- Added additional output, and opt out messages.
- Adjusted directory and files permissions.

* Mon Nov 3 2003 Byron Young <spamiccling@yahoo.com>
- created initial rpm for RH9
